==> huaweicloudsdkmetastudio-3.1.143-py2.py3-none-any.whl: huaweicloudsdkmetastudio/v1/model/show_welcome_speech_switch_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowWelcomeSpeechSwitchRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'x_app_user_id': 'str',
        'robot_id': 'str',
        'language': 'str'
    }

    attribute_map = {
        'x_app_user_id': 'X-App-UserId',
        'robot_id': 'robot_id',
        'language': 'language'
    }

    def __init__(self, x_app_user_id=None, robot_id=None, language=None):
        r"""ShowWelcomeSpeechSwitchRequest

        The model defined in huaweicloud sdk

        :param x_app_user_id: 第三方用户ID。不允许输入中文。
        :type x_app_user_id: str
        :param robot_id: 应用ID。
        :type robot_id: str
        :param language: 智能交互语言  * CN:中文  * EN:英文
        :type language: str
        """
        
        

        self._x_app_user_id = None
        self._robot_id = None
        self._language = None
        self.discriminator = None

        if x_app_user_id is not None:
            self.x_app_user_id = x_app_user_id
        self.robot_id = robot_id
        if language is not None:
            self.language = language

    @property
    def x_app_user_id(self):
        r"""Gets the x_app_user_id of this ShowWelcomeSpeechSwitchRequest.

        第三方用户ID。不允许输入中文。

        :return: The x_app_user_id of this ShowWelcomeSpeechSwitchRequest.
        :rtype: str
        """
        return self._x_app_user_id

    @x_app_user_id.setter
    def x_app_user_id(self, x_app_user_id):
        r"""Sets the x_app_user_id of this ShowWelcomeSpeechSwitchRequest.

        第三方用户ID。不允许输入中文。

        :param x_app_user_id: The x_app_user_id of this ShowWelcomeSpeechSwitchRequest.
        :type x_app_user_id: str
        """
        self._x_app_user_id = x_app_user_id

    @property
    def robot_id(self):
        r"""Gets the robot_id of this ShowWelcomeSpeechSwitchRequest.

        应用ID。

        :return: The robot_id of this ShowWelcomeSpeechSwitchRequest.
        :rtype: str
        """
        return self._robot_id

    @robot_id.setter
    def robot_id(self, robot_id):
        r"""Sets the robot_id of this ShowWelcomeSpeechSwitchRequest.

        应用ID。

        :param robot_id: The robot_id of this ShowWelcomeSpeechSwitchRequest.
        :type robot_id: str
        """
        self._robot_id = robot_id

    @property
    def language(self):
        r"""Gets the language of this ShowWelcomeSpeechSwitchRequest.

        智能交互语言  * CN:中文  * EN:英文

        :return: The language of this ShowWelcomeSpeechSwitchRequest.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        r"""Sets the language of this ShowWelcomeSpeechSwitchRequest.

        智能交互语言  * CN:中文  * EN:英文

        :param language: The language of this ShowWelcomeSpeechSwitchRequest.
        :type language: str
        """
        self._language = language

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowWelcomeSpeechSwitchRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmetastudio-3.1.153-py2.py3-none-any.whl: huaweicloudsdkmetastudio/v1/model/show_welcome_speech_switch_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowWelcomeSpeechSwitchRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'x_app_user_id': 'str',
        'robot_id': 'str',
        'language': 'str'
    }

    attribute_map = {
        'x_app_user_id': 'X-App-UserId',
        'robot_id': 'robot_id',
        'language': 'language'
    }

    def __init__(self, x_app_user_id=None, robot_id=None, language=None):
        r"""ShowWelcomeSpeechSwitchRequest

        The model defined in huaweicloud sdk

        :param x_app_user_id: 第三方用户ID。不允许输入中文。
        :type x_app_user_id: str
        :param robot_id: 应用ID。
        :type robot_id: str
        :param language: 智能交互语言  * CN:中文  * EN:英文  * ESP：西班牙语（仅海外站点支持）  * por：葡萄牙语（仅海外站点支持）  * Arabic：阿拉伯语（仅海外站点支持）  * Thai：泰语（仅海外站点支持）
        :type language: str
        """
        
        

        self._x_app_user_id = None
        self._robot_id = None
        self._language = None
        self.discriminator = None

        if x_app_user_id is not None:
            self.x_app_user_id = x_app_user_id
        self.robot_id = robot_id
        if language is not None:
            self.language = language

    @property
    def x_app_user_id(self):
        r"""Gets the x_app_user_id of this ShowWelcomeSpeechSwitchRequest.

        第三方用户ID。不允许输入中文。

        :return: The x_app_user_id of this ShowWelcomeSpeechSwitchRequest.
        :rtype: str
        """
        return self._x_app_user_id

    @x_app_user_id.setter
    def x_app_user_id(self, x_app_user_id):
        r"""Sets the x_app_user_id of this ShowWelcomeSpeechSwitchRequest.

        第三方用户ID。不允许输入中文。

        :param x_app_user_id: The x_app_user_id of this ShowWelcomeSpeechSwitchRequest.
        :type x_app_user_id: str
        """
        self._x_app_user_id = x_app_user_id

    @property
    def robot_id(self):
        r"""Gets the robot_id of this ShowWelcomeSpeechSwitchRequest.

        应用ID。

        :return: The robot_id of this ShowWelcomeSpeechSwitchRequest.
        :rtype: str
        """
        return self._robot_id

    @robot_id.setter
    def robot_id(self, robot_id):
        r"""Sets the robot_id of this ShowWelcomeSpeechSwitchRequest.

        应用ID。

        :param robot_id: The robot_id of this ShowWelcomeSpeechSwitchRequest.
        :type robot_id: str
        """
        self._robot_id = robot_id

    @property
    def language(self):
        r"""Gets the language of this ShowWelcomeSpeechSwitchRequest.

        智能交互语言  * CN:中文  * EN:英文  * ESP：西班牙语（仅海外站点支持）  * por：葡萄牙语（仅海外站点支持）  * Arabic：阿拉伯语（仅海外站点支持）  * Thai：泰语（仅海外站点支持）

        :return: The language of this ShowWelcomeSpeechSwitchRequest.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        r"""Sets the language of this ShowWelcomeSpeechSwitchRequest.

        智能交互语言  * CN:中文  * EN:英文  * ESP：西班牙语（仅海外站点支持）  * por：葡萄牙语（仅海外站点支持）  * Arabic：阿拉伯语（仅海外站点支持）  * Thai：泰语（仅海外站点支持）

        :param language: The language of this ShowWelcomeSpeechSwitchRequest.
        :type language: str
        """
        self._language = language

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowWelcomeSpeechSwitchRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
